Spectral Recovery and Up-sampling
=================================

Reflectance Recovery
--------------------

CIE XYZ Colourspace to Spectral
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_sd
    XYZ_TO_SD_METHODS

Jakob and Hanika (2019)
~~~~~~~~~~~~~~~~~~~~~~~

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    XYZ_to_sd_Jakob2019
    LUT3D_Jakob2019

**Ancillary Objects**

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    sd_Jakob2019
    find_coefficients_Jakob2019

Mallett and Yuksel (2019)
~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    RGB_to_sd_Mallett2019

**Ancillary Objects**

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    MSDS_BASIS_FUNCTIONS_sRGB_MALLETT2019
    SPECTRAL_SHAPE_sRGB_MALLETT2019
    spectral_primary_decomposition_Mallett2019

Meng, Simon and Hanika (2015)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    XYZ_to_sd_Meng2015

Otsu, Yamamoto and Hachisuka (2018)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    XYZ_to_sd_Otsu2018

**Ancillary Objects**

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    Dataset_Otsu2018
    Tree_Otsu2018

Smits (1999)
~~~~~~~~~~~~

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    RGB_to_sd_Smits1999
    SDS_SMITS1999

Camera RGB Sensitivities Recovery
---------------------------------

Jiang, Liu, Gu and Süsstrunk (2013)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    RGB_to_sd_camera_sensitivity_Jiang2013
    RGB_to_msds_camera_sensitivities_Jiang2013

**Ancillary Objects**

``colour.recovery``

.. currentmodule:: colour.recovery

.. autosummary::
    :toctree: generated/

    PCA_Jiang2013
